@@ -11,7 +11,7 @@
 #define HAVE_GET_CREDENTIALS_OPENBSD
 //#define HAVE_GET_CREDENTIALS_FREEBSD
 #define HAVE_GETPEEREID
-//#define HAVE_FDATASYNC
+#define HAVE_FDATASYNC
 //#define HAVE_NETDB_REENTRANT
 #if defined(HAVE_GET_CREDENTIALS_LINUX) || defined(HAVE_GET_CREDENTIALS_NETBSD) || defined(HAVE_GET_CREDENTIALS_OPENBSD) || defined(HAVE_GET_CREDENTIALS_FREEBSD) || defined(HAVE_GETPEEREID)
 #  define HAVE_GET_CREDENTIALS
